==> jc-1.4.0.tar.gz: javax/print/attribute/HashPrintServiceAttributeSet.h <==
// public class javax.print.attribute.HashPrintServiceAttributeSet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5ac41f29c14cfdf4 javax_print_attribute_HashAttributeSet
// @dep_class 8818be66a5255d9d javax_print_attribute_HashPrintServiceAttributeSet

// header file dependencies
// @dep_header javax_print_attribute_HashAttributeSet

#include "javax/print/attribute/HashAttributeSet.h"

#ifndef _JC_javax_print_attribute_HashPrintServiceAttributeSet_H_
#define _JC_javax_print_attribute_HashPrintServiceAttributeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_attribute_PrintServiceAttribute$object;
struct _jc_javax_print_attribute_PrintServiceAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$sub_refs	_jc_javax_print_attribute_HashPrintServiceAttributeSet$sub_refs;
typedef struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$sub_nonrefs	_jc_javax_print_attribute_HashPrintServiceAttributeSet$sub_nonrefs;
typedef struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$refs	_jc_javax_print_attribute_HashPrintServiceAttributeSet$refs;
typedef struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$nonrefs	_jc_javax_print_attribute_HashPrintServiceAttributeSet$nonrefs;
typedef struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$object	_jc_javax_print_attribute_HashPrintServiceAttributeSet$object;

typedef struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$fields_struct	_jc_javax_print_attribute_HashPrintServiceAttributeSet$fields_struct;
typedef const struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$vmethods	_jc_javax_print_attribute_HashPrintServiceAttributeSet$vmethods;
typedef const struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$vtable	_jc_javax_print_attribute_HashPrintServiceAttributeSet$vtable;
typedef const struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$vtype	_jc_javax_print_attribute_HashPrintServiceAttributeSet$vtype;

// Class fields structure
struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24PrintServiceAttribute;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_HashPrintServiceAttributeSet$fields_struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$class_fields;

// Constructors
extern void _jc_javax_print_attribute_HashPrintServiceAttributeSet$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$object *);
extern void _jc_javax_print_attribute_HashPrintServiceAttributeSet$method$_init$67e0361dcab869a2(_jc_env *, struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$object *, struct _jc_object *);
extern void _jc_javax_print_attribute_HashPrintServiceAttributeSet$method$_init$8dd1ca2c0646d12a(_jc_env *, struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$object *, struct _jc_object *);
extern void _jc_javax_print_attribute_HashPrintServiceAttributeSet$method$_init$0728126afd9a085f(_jc_env *, struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$object *, struct _jc_object_array *);

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_HashPrintServiceAttributeSet$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_HashAttributeSet$vmethods	javax_print_attribute_HashAttributeSet;
	_jc_javax_print_attribute_HashPrintServiceAttributeSet$vmethods	javax_print_attribute_HashPrintServiceAttributeSet;
};

// Vtype
struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_HashPrintServiceAttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$refs {
    _jc_javax_print_attribute_HashPrintServiceAttributeSet$sub_refs	javax_print_attribute_HashPrintServiceAttributeSet;
    _jc_javax_print_attribute_HashAttributeSet$sub_refs	javax_print_attribute_HashAttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_HashAttributeSet$sub_nonrefs	javax_print_attribute_HashAttributeSet;
    _jc_javax_print_attribute_HashPrintServiceAttributeSet$sub_nonrefs	javax_print_attribute_HashPrintServiceAttributeSet;
};

// Object instance structure
struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$object {
	_jc_javax_print_attribute_HashPrintServiceAttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_HashPrintServiceAttributeSet$vtype	*vtype;
	_jc_javax_print_attribute_HashPrintServiceAttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_HashPrintServiceAttributeSet$vtype _jc_javax_print_attribute_HashPrintServiceAttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_HashPrintServiceAttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_HashPrintServiceAttributeSet$class_object;

#endif	/* _JC_javax_print_attribute_HashPrintServiceAttributeSet_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/HashPrintServiceAttributeSet.h <==
// public class javax.print.attribute.HashPrintServiceAttributeSet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5ac41f29c14cfdf4 javax_print_attribute_HashAttributeSet
// @dep_class 8818be66a5255d9d javax_print_attribute_HashPrintServiceAttributeSet

// header file dependencies
// @dep_header javax_print_attribute_HashAttributeSet

#include "javax/print/attribute/HashAttributeSet.h"

#ifndef _JC_javax_print_attribute_HashPrintServiceAttributeSet_H_
#define _JC_javax_print_attribute_HashPrintServiceAttributeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_attribute_PrintServiceAttribute$object;
struct _jc_javax_print_attribute_PrintServiceAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$sub_refs	_jc_javax_print_attribute_HashPrintServiceAttributeSet$sub_refs;
typedef struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$sub_nonrefs	_jc_javax_print_attribute_HashPrintServiceAttributeSet$sub_nonrefs;
typedef struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$refs	_jc_javax_print_attribute_HashPrintServiceAttributeSet$refs;
typedef struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$nonrefs	_jc_javax_print_attribute_HashPrintServiceAttributeSet$nonrefs;
typedef struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$object	_jc_javax_print_attribute_HashPrintServiceAttributeSet$object;

typedef struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$fields_struct	_jc_javax_print_attribute_HashPrintServiceAttributeSet$fields_struct;
typedef const struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$vmethods	_jc_javax_print_attribute_HashPrintServiceAttributeSet$vmethods;
typedef const struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$vtable	_jc_javax_print_attribute_HashPrintServiceAttributeSet$vtable;
typedef const struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$vtype	_jc_javax_print_attribute_HashPrintServiceAttributeSet$vtype;

// Class fields structure
struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24PrintServiceAttribute;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_HashPrintServiceAttributeSet$fields_struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$class_fields;

// Constructors
extern void _jc_javax_print_attribute_HashPrintServiceAttributeSet$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$object *) _JC_JCNI_ATTR;
extern void _jc_javax_print_attribute_HashPrintServiceAttributeSet$method$_init$67e0361dcab869a2(_jc_env *, struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_print_attribute_HashPrintServiceAttributeSet$method$_init$8dd1ca2c0646d12a(_jc_env *, struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_print_attribute_HashPrintServiceAttributeSet$method$_init$0728126afd9a085f(_jc_env *, struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_HashPrintServiceAttributeSet$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_HashAttributeSet$vmethods	javax_print_attribute_HashAttributeSet;
	_jc_javax_print_attribute_HashPrintServiceAttributeSet$vmethods	javax_print_attribute_HashPrintServiceAttributeSet;
};

// Vtype
struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_HashPrintServiceAttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$refs {
    _jc_javax_print_attribute_HashPrintServiceAttributeSet$sub_refs	javax_print_attribute_HashPrintServiceAttributeSet;
    _jc_javax_print_attribute_HashAttributeSet$sub_refs	javax_print_attribute_HashAttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_HashAttributeSet$sub_nonrefs	javax_print_attribute_HashAttributeSet;
    _jc_javax_print_attribute_HashPrintServiceAttributeSet$sub_nonrefs	javax_print_attribute_HashPrintServiceAttributeSet;
};

// Object instance structure
struct _jc_javax_print_attribute_HashPrintServiceAttributeSet$object {
	_jc_javax_print_attribute_HashPrintServiceAttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_HashPrintServiceAttributeSet$vtype	*vtype;
	_jc_javax_print_attribute_HashPrintServiceAttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_HashPrintServiceAttributeSet$vtype _jc_javax_print_attribute_HashPrintServiceAttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_HashPrintServiceAttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_HashPrintServiceAttributeSet$class_object;

#endif	/* _JC_javax_print_attribute_HashPrintServiceAttributeSet_H_ */
